%define _no_lto 1

%define major 1.0.2
%global soversion 10

%define with_krb5 %{?_with_krb5:1}%{!?_with_krb5:0}

# Usually we don't package development files for compat packages
%bcond_with devfiles

Summary:	Secure Sockets Layer communications libs & utils
Name:		compat-openssl10
Version:	1.0.2u
Release:	1%{dist}
Epoch: 1
License:	BSD-like
Group:		System/Libraries
Url:		http://www.openssl.org/
Source0:	http://ftp.openssl.org/source/openssl-%{version}.tar.gz
Source1:	http://ftp.openssl.org/source/openssl-%{version}.tar.gz.asc
Source2:	Makefile.certificate
Source3:	make-dummy-cert
Source4:	openssl-thread-test.c
# (gb) 0.9.7b-4mdk: Handle RPM_OPT_FLAGS in Configure
Patch2:		openssl-1.0.2e-optflags.patch
# (oe) support Brazilian Government OTHERNAME X509v3 field (#14158)
# http://www.iti.gov.br/resolucoes/RESOLU__O_13_DE_26_04_2002.PDF
Patch6:		openssl-0.9.8-beta6-icpbrasil.diff
Patch7:		openssl-1.0.0-defaults.patch
Patch8:		openssl-0.9.8a-link-krb5.patch
Patch10:	openssl-0.9.7-beta6-ia64.patch
Patch12:	openssl-0.9.6-x509.patch
Patch13:	openssl-0.9.7-beta5-version-add-engines.patch
Patch16:	openssl-1.0.1c-fix-perlpath.pl
# MIPS and ARM support
Patch300:	openssl-1.0.2a-mips.patch
Patch301:	openssl-1.0.2a-arm.patch
Patch302:	openssl-1.0.0-enginesdir.patch
Patch303:	openssl-0.9.8a-no-rpath.patch
# # add symbol versioning to prevent conflicts with openssl 1.1 symbols (Debian)
Patch304:	openssl-1.0-versioned-symbols.patch

BuildRequires: gcc
BuildRequires: coreutils, perl-interpreter, perl-generators, sed, zlib-devel, /usr/bin/cmp
BuildRequires: lksctp-tools-devel
BuildRequires: /usr/bin/rename
BuildRequires: /usr/bin/pod2man
Requires: coreutils, make
Requires: crypto-policies
Conflicts: openssl < 1:1.1.0, openssl-libs < 1:1.1.0

%description
The OpenSSL toolkit provides support for secure communications between
machines. This version of OpenSSL package contains only the libraries
and is provided for compatibility with previous releases and software
that does not support compilation with OpenSSL-1.1.

%package devel
Summary: Files for development of applications which have to use OpenSSL-1.0.2
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{epoch}:%{version}-%{release}
Requires: zlib-devel%{?_isa}
Requires: pkgconfig
# The devel subpackage intentionally conflicts with main openssl-devel
# as simultaneous use of both openssl package cannot be encouraged.
# Making the packages non-conflicting would also require further
# changes in the dependent packages.
#Conflicts: openssl-devel

%description devel
The OpenSSL toolkit provides support for secure communications between
machines. This version of OpenSSL package contains only the libraries
and is provided for compatibility with previous releases and software
that does not support compilation with OpenSSL-1.1. This package
contains include files needed to develop applications which
support various cryptographic algorithms and protocols.

%prep
%setup -qn openssl-%{version}
%patch2 -p1 -b .optflags
#patch6 -p1 -b .icpbrasil
%patch7 -p1 -b .defaults
%{?_with_krb5:%patch8 -p1 -b .krb5}
#patch10 -p0 -b .ia64
%patch12 -p1 -b .x509
%patch13 -p1 -b .version-add-engines
%patch16 -p1 -b .perlfind~

%patch300 -p1 -b .mips
%patch301 -p1 -b .arm
%patch302 -p1 -b .engines
%patch303 -p1 -b .no-rpath
%patch304 -p1


perl -pi -e "s,^(OPENSSL_LIBNAME=).+$,\1%{_lib}," Makefile.org engines/Makefile

sed -i 's/SHLIB_VERSION_NUMBER "1.0.0"/SHLIB_VERSION_NUMBER "%{version}"/' crypto/opensslv.h

# fix perl path
perl util/perlpath.pl %{_bindir}/perl

cp %{SOURCE2} Makefile.certificate
cp %{SOURCE3} make-dummy-cert
cp %{SOURCE4} openssl-thread-test.c

%build

# Figure out which flags we want to use.
# default
sslarch=%{_os}-%{_arch}
%ifarch %ix86
sslarch=linux-elf
if ! echo %{_target} | grep -q i[56]86 ; then
    sslflags="no-asm"
fi
%endif
%ifarch sparcv9
sslarch=linux-sparcv9
%endif
%ifarch alpha
sslarch=linux-alpha-gcc
%endif
%ifarch s390
sslarch="linux-generic32 -DB_ENDIAN -DNO_ASM"
%endif
%ifarch s390x
sslarch="linux-generic64 -DB_ENDIAN -DNO_ASM"
%endif
%ifarch %{arm}
sslarch=linux-generic32
%endif
%ifarch aarch64
sslarch=linux-generic32
%endif

# ia64, x86_64, ppc, ppc64 are OK by default
# Configure the build tree.  Override OpenSSL defaults with known-good defaults
# usable on all platforms.  The Configure script already knows to use -fPIC and
# RPM_OPT_FLAGS, so we can skip specifiying them here.
./Configure \
	--openssldir=%{_sysconfdir}/pki/tls ${sslflags} \
	--enginesdir=%{_libdir}/openssl%{soversion}/engines \
	--prefix=%{_prefix} \
	%{?_with_krb5:--with-krb5-flavor=MIT} \
	zlib no-idea no-rc5 enable-camellia enable-seed enable-tlsext enable-rfc3779 enable-cms shared ${sslarch}

# Add -Wa,--noexecstack here so that libcrypto's assembler modules will be
# marked as not requiring an executable stack.
# Also add -DPURIFY to make using valgrind with openssl easier as we do not
# want to depend on the uninitialized memory as a source of entropy anyway.
RPM_OPT_FLAGS="$RPM_OPT_FLAGS -Wa,--noexecstack -DPURIFY"
make depend
make all

# Generate hashes for the included certs.
make rehash

#check
# Verify that what was compiled actually works.
#export LD_LIBRARY_PATH=`pwd`${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}

#make -C test apps tests

#gcc -o openssl-thread-test \
#    %{?_with_krb5:`krb5-config --cflags`} \
#    -I./include \
#    %{optflags} \
#    openssl-thread-test.c \
#    -L. -lssl -lcrypto \
#    %{?_with_krb5:`krb5-config --libs`} \
#    -lpthread -lz -ldl

#./openssl-thread-test --threads %{thread_test_threads}

%install

# Install OpenSSL.
install -d $RPM_BUILD_ROOT{%{_bindir},%{_includedir},%{_libdir},%{_mandir},%{_libdir}/openssl%{soversion},%{_includedir}/openssl%{soversion}}
make INSTALL_PREFIX=$RPM_BUILD_ROOT install
make INSTALL_PREFIX=$RPM_BUILD_ROOT install_docs

mv $RPM_BUILD_ROOT%{_sysconfdir}/pki/tls/man/* $RPM_BUILD_ROOT%{_mandir}/
rmdir $RPM_BUILD_ROOT%{_sysconfdir}/pki/tls/man

mv %{buildroot}%{_includedir}/openssl %{buildroot}%{_includedir}/openssl%{soversion}/

rm -f %{buildroot}%{_libdir}/libcrypto.so
rm -f %{buildroot}%{_libdir}/libssl.so

ln -srf %{buildroot}/%{_libdir}/libcrypto.so.%{major} %{buildroot}%{_libdir}/openssl%{soversion}/libcrypto.so
ln -srf %{buildroot}/%{_libdir}/libssl.so.%{major} %{buildroot}%{_libdir}/openssl%{soversion}/libssl.so

# the makefiles is too borked...
mv %{buildroot}%{_libdir}/engines %{buildroot}%{_libdir}/openssl%{soversion}/engines


# Delete static library
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a || :

# Rename man pages so that they don't conflict with other system man pages.
pushd $RPM_BUILD_ROOT%{_mandir}
for manpage in man*/* ; do
	if [ -L ${manpage} ]; then
		TARGET=`ls -l ${manpage} | awk '{ print $NF }'`
		ln -snf ${TARGET}ssl ${manpage}ssl
		rm -f ${manpage}
	else
		mv ${manpage} ${manpage}ssl
	fi
done
popd

# Delete non-devel man pages in the compat package
rm -rf $RPM_BUILD_ROOT%{_mandir}/man[157]*

# Delete configuration files
rm -rf  $RPM_BUILD_ROOT%{_sysconfdir}/pki/*

# Remove binaries
rm -rf $RPM_BUILD_ROOT/%{_bindir}

# Remove pkgconfig files
rm -rf $RPM_BUILD_ROOT%{_libdir}/pkgconfig

# Install compat config file
install -m 644 apps/openssl.cnf $RPM_BUILD_ROOT%{_sysconfdir}/pki/openssl10.cnf

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license LICENSE
%doc FAQ NEWS README
%dir %{_libdir}/openssl%{soversion}
%{_libdir}/lib*.so.%{major}*
%dir %{_libdir}/openssl%{soversion}/engines
%{_libdir}/openssl%{soversion}/engines/*.so
%dir %{_sysconfdir}/pki
%attr(0644,root,root) %{_sysconfdir}/pki/openssl10.cnf


%files devel
%doc CHANGES doc/*
%doc FAQ INSTALL LICENSE NEWS PROBLEMS README*
%dir %{_includedir}/openssl%{soversion}/openssl
%{_includedir}/openssl%{soversion}/openssl/*
%{_libdir}/openssl%{soversion}/lib*.so
#{_libdir}/pkgconfig/*
#{_libdir}/openssl%{soversion}/lib*.a
%exclude %{_mandir}/man3/*